function pluralize(time, label) {
  if (time === 1) {
    return time + label;
  }
  return time + label + "s";
}

/**
 * 日期格式化
 */
export function dateFormat(date) {
  let format = "yyyy-MM-dd hh:mm:ss";
  if (date !== "Invalid Date") {
    var o = {
      "M+": date.getMonth() + 1, // month
      "d+": date.getDate(), // day
      "h+": date.getHours(), // hour
      "m+": date.getMinutes(), // minute
      "s+": date.getSeconds(), // second
      "q+": Math.floor((date.getMonth() + 3) / 3), // quarter
      S: date.getMilliseconds() // millisecond
    };
    if (/(y+)/.test(format)) {
      format = format.replace(
        RegExp.$1,
        (date.getFullYear() + "").substr(4 - RegExp.$1.length)
      );
    }
    for (var k in o) {
      if (new RegExp("(" + k + ")").test(format)) {
        format = format.replace(
          RegExp.$1,
          RegExp.$1.length === 1
            ? o[k]
            : ("00" + o[k]).substr(("" + o[k]).length)
        );
      }
    }
    return format;
  }
  return "";
}

export function timeAgo(time) {
  const between = Date.now() / 1000 - Number(time);
  if (between < 3600) {
    return pluralize(~~(between / 60), " minute");
  } else if (between < 86400) {
    return pluralize(~~(between / 3600), " hour");
  } else {
    return pluralize(~~(between / 86400), " day");
  }
}

export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null;
  }

  if ((time + "").length === 10) {
    time = +time * 1000;
  }

  const format = cFormat || "{y}-{m}-{d} {h}:{i}:{s}";
  let date;
  if (typeof time === "object") {
    date = time;
  } else {
    date = new Date(parseInt(time, 10));
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  };
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key];
    if (key === "a")
      return ["一", "二", "三", "四", "五", "六", "日"][value - 1];
    if (result.length > 0 && value < 10) {
      value = "0" + value;
    }
    return value || 0;
  });
  return time_str;
}

export function formatTime(time, option) {
  time = +time * 1000;
  const d = new Date(time);
  const now = Date.now();

  const diff = (now - d) / 1000;

  if (diff < 30) {
    return "刚刚";
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + "分钟前";
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + "小时前";
  } else if (diff < 3600 * 24 * 2) {
    return "1天前";
  }
  if (option) {
    return parseTime(time, option);
  } else {
    return (
      d.getMonth() +
      1 +
      "月" +
      d.getDate() +
      "日" +
      d.getHours() +
      "时" +
      d.getMinutes() +
      "分"
    );
  }
}

/* 数字 格式化 */
export function nFormatter(num, digits) {
  const si = [
    { value: 1e18, symbol: "E" },
    { value: 1e15, symbol: "P" },
    { value: 1e12, symbol: "T" },
    { value: 1e9, symbol: "G" },
    { value: 1e6, symbol: "M" },
    { value: 1e3, symbol: "k" }
  ];
  for (let i = 0; i < si.length; i++) {
    if (num >= si[i].value) {
      return (
        (num / si[i].value + 0.1)
          .toFixed(digits)
          .replace(/\.0+$|(\.[0-9]*[1-9])0+$/, "$1") + si[i].symbol
      );
    }
  }
  return num.toString();
}

export function html2Text(val) {
  const div = document.createElement("div");
  div.innerHTML = val;
  return div.textContent || div.innerText;
}

export function toThousandslsFilter(num) {
  return (+num || 0)
    .toString()
    .replace(/^-?\d+/g, m => m.replace(/(?=(?!\b)(\d{3})+$)/g, ","));
}

export function filterNoteStatus(arg) {
  let filterObj = {
    0: "未结算",
    1: "结算成功",
    2: "结算失败",
    3: "已提交结算",
    9: "申请结算"
  };
  return filterObj[arg];
}

export function filterSubType(arg) {
  let filterObj = {
    "0": "人力家",
    "1": "税邦云",
    "2": "钉灵工-海南飞亿",
    "3": "易联",
    "4": "金园数科",
    "5": "钉灵工-河南薪泰梓",
    "12": "钉灵工-河南兆宇",
    "6": "安之慧"
  };
  return filterObj[arg];
}

export function filterCertStatus(arg) {
  let filterObj = {
    1: "认证成功",
    2: "认证失败",
    3: "认证中",
    4: "未认证",
    10: "未增员",
    11: "已增员",
    12: "已认证未绑卡",
    13: "认证中已绑卡",
    14: "认证中未绑卡",
    15: "已认证",
    16: "未认证已绑卡"
  };
  return filterObj[arg];
}

export function filterSujectLocation(arg) {
  const filterObj = {
    // 仁励家通道
    REN_LI_JIA: "人力家",
    // 税邦云通道
    ZHONG_YING: "湖南众盈",
    LUO_SHU_YUN: "税邦云", // 永州罗数云, 暂时定为税邦云
    // 钉灵工通道
    FEI_YI: "钉灵工-海南飞亿",
    JIN_YUAN: "金园数科",
    XIN_TAI_ZI: "钉灵工-河南薪泰梓",
    ZHAO_YU: "钉灵工-河南兆宇",
    ZHENG_QI_ZHI_XING: "安之慧",
    LANG_CHAO: "浪潮",
    JIANG_XI: "正启之星-江西",
    HUI_QI_YUN: "汇企云",
    ZHONG_YI_YUN: "众蚁云",
    ZHONG_ZHI: "中智",
    QI_FU: "福建企赋",
    SHEN_ZHEN_REN_CAI: "深圳之光",
    YI_MA: "易马财税",
    XIN_SHI_YI: "薪事易-海南飞亿",
    HE_CHUANG_ZHONG_ZHI: "合创众盈-天津中智",
    HE_CHUANG_REN_CAI_YUN: "合创众盈-福州人才云"
  };
  return filterObj[arg];
}
